# remirepo spec file for php-pecl-nsq
#
# SPDX-FileCopyrightText:  Copyright 2018-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%if 0%{?scl:1}
%scl_package       php-pecl-nsq
%else
%global _root_prefix %{_prefix}
%endif

%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   nsq
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:       PHP extension for NSQ client
Name:          %{?scl_prefix}php-pecl-nsq
Version:       3.5.1
Release:       3%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
Source:        https://pecl.php.net/get/%{sources}%{?prever}.tgz
License:       PHP-3.01
URL:           https://pecl.php.net/package/nsq

Patch0:        0001-fix-prototype.patch

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.0
BuildRequires: %{?scl_prefix}php-json
BuildRequires: %{?scl_prefix}php-pear
BuildRequires: pkgconfig(libevent) >= 2

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
Requires:      %{?scl_prefix}php-json%{?_isa}

Provides:      %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:      %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This extension is a NSQ client .NSQ is a message queue system which like Kafka.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1 -b .proto

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_NSQ_VERSION/{s/.* "//;s/".*$//;p}' php_nsq.h )
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir  ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable %{summary}
extension = %{pecl_name}.so
EOF




%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
  --with-nsq \
  --with-libevent-path=%{_root_prefix} \
  --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
  --with-nsq \
  --with-libevent-path=%{_root_prefix} \
  --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

: Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

: Install the ZTS stuff
%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

: Install the package XML file
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

: Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}
OPTS="-n"
[ -f %{php_extdir}/json.so     ] && OPTS="$OPTS -d extension=json.so"

: Minimal load test for NTS extension
%{__php} $OPTS \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="$OPTS -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} $OPTS \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="$OPTS -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%endif


%changelog
* Thu Feb 20 2025 Remi Collet <remi@remirepo.net> - 3.5.1-3
- fix lookup function prototype using patch from
  https://github.com/yunnian/php-nsq/pull/76
- re-license spec file to CECILL-2.1

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 3.5.1-2
- build out of sources tree

* Sat Sep 18 2021 Remi Collet <remi@remirepo.net> - 3.5.1-1
- update to 3.5.1

* Tue Oct 15 2019 Remi Collet <remi@remirepo.net> - 3.5.0-1
- update to 3.5.0

* Wed Sep 18 2019 Remi Collet <remi@remirepo.net> - 3.4.3-1
- update to 3.4.3

* Tue Sep 17 2019 Remi Collet <remi@remirepo.net> - 3.4.2-1
- update to 3.4.2

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 3.4.1-3
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 3.4.1-2
- rebuild for 7.4.0beta1

* Tue Jun 11 2019 Remi Collet <remi@remirepo.net> - 3.4.1-1
- update to 3.4.1

* Tue Oct 23 2018 Remi Collet <remi@remirepo.net> - 3.4.0-1
- update to 3.4.0

* Mon Oct 22 2018 Remi Collet <remi@remirepo.net> - 3.3.0-1
- update to 3.3.0

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 3.1.0-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 3.1.0-2
- rebuild for 7.3.0alpha4 new ABI

* Sun Jul  1 2018 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0

* Thu Jun 21 2018 Remi Collet <remi@remirepo.net> - 3.0-1
- update to 3.0

* Tue May 29 2018 Remi Collet <remi@remirepo.net> - 2.4.0-1
- update to 2.4.0
- drop patches merged upstream

* Thu Mar 22 2018 Remi Collet <remi@remirepo.net> - 2.3.2-1
- initial package, version 2.3.2 (stable)
- open https://github.com/yunnian/php-nsq/pull/19 - json dependency
- open https://github.com/yunnian/php-nsq/pull/20 - examples role
- open https://github.com/yunnian/php-nsq/pull/21 - missing include
